/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "pokergame.h"

primitive_t primitive;
primitive_t dot;
float x, y;

bool pokerGameInit(game_t *game) {
  pokergame_t *pokerGame = &game->pokerGame;

  // Load the Assets
  pokerGameAssetsInit(&pokerGame->assets);

  // Initialize the UI.
  pokerUiInit(pokerGame);
  
  // Prep the VN Conversation Engine.
  vnSceneInit(&pokerGame->scene, &pokerGame->assets.font, &pokerGame->assets.testTexture);
  pokerGameActionStartAdd(pokerGame);
  queueNext(&pokerGame->scene.conversation.actionQueue);

  // 
  quadInit(&primitive, 0,  0,0,0,0,  64,64,1,1);
  quadInit(&dot, 0,  0,0,0,0,  2,2,1,1);
  x = 0, y = 0;

  return true;
} 

void pokerGameUpdate(game_t *game) {
  pokergame_t *pokerGame;
  pokerGame = &game->pokerGame;

  // Update the scene
  // vnSceneUpdate(&pokerGame->scene, &game->engine);

  // Bind the shader.
  shaderUse(&pokerGame->assets.shader);


  // Render the visual novel scene
  // vnSceneRenderWorld(&pokerGame->scene, &game->engine, &pokerGame->assets.shader);
  vnSceneRenderGui(&pokerGame->scene, &game->engine, &pokerGame->assets.shader);

  shaderUseTexture(&pokerGame->assets.shader, &pokerGame->assets.testTexture);

  x = inputGetAxis(&game->engine.input, INPUT_MOUSE_X);
  y = inputGetAxis(&game->engine.input, INPUT_MOUSE_Y);
  
  aabbpointhit_t hitting;
  bool hit = aabbPoint2D(x, y, 64,64, 64,64, &hitting);

  shaderUsePosition(&pokerGame->assets.shader,  64,64,0,  0,0,0);
  primitiveDraw(&primitive, 0, -1);

  if(hit) {
    shaderUsePosition(&pokerGame->assets.shader,  hitting.hitX,hitting.hitY,0,  0,0,0);
  } else {
    shaderUsePosition(&pokerGame->assets.shader,  x,y,0,  0,0,0);
  }
  primitiveDraw(&dot, 0, -1);

  // pokerUiRender(pokerGame);
}

void pokerGameDispose(game_t *game) {
  pokerUiDispose(&game->pokerGame);
  vnSceneDispose(&game->pokerGame.scene);
  pokerGameAssetsDispose(&game->pokerGame.assets);
}